summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--hints/linux.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/hints/linux.sh b/hints/linux.sh
index 61d9fc8e5e..2ed31dbef3 100644
--- a/hints/linux.sh
+++ b/hints/linux.sh
@@ -39,9 +39,10 @@ d_suidsafe='undef'
# do the implicit mapping.
ignore_versioned_solibs='y'
-# BSD compatability library no longer needed
-# 'kaffe' has a /usr/lib/libnet.so which is not at all relevent for perl.
-set `echo X "$libswanted "| sed -e 's/ bsd / /' -e 's/ net / /'`
+# BSD compatibility library no longer needed
+# 'kaffe' has a /usr/lib/libnet.so which is not at all relevant for perl.
+# bind causes issues with several reentrant functions
+set `echo X "$libswanted "| sed -e 's/ bsd / /' -e 's/ net / /' -e 's/ bind / /'`
shift
libswanted="$*"